uitpGvAndBgDesc <-
  tabPanel("Genetic Value Analysis and Breeding Group Description",
           includeHTML("../extdata/ui_guidance/gvAndBgDesc.html"))
